"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildConfig = exports.isTransactionIdentifier = exports.resolveWrappedToken = exports.canonicalAddress = exports.isSameToken = exports.isTokenId = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const address_1 = require("./address");
const contracts_1 = require("./contracts");
function isTokenId(thing) {
    return (typeof thing === "object" &&
        thing.address !== undefined &&
        thing.chain !== undefined &&
        (0, sdk_base_1.isChain)(thing.chain));
}
exports.isTokenId = isTokenId;
function isSameToken(a, b) {
    if (a.chain !== b.chain)
        return false;
    return canonicalAddress(a) === canonicalAddress(b);
}
exports.isSameToken = isSameToken;
function canonicalAddress(ca) {
    // @ts-ignore
    return ca.address.toNative(ca.chain).toString();
}
exports.canonicalAddress = canonicalAddress;
// Given a token id, address, or the const string 'native' return
// a TokenId representing either the token itself or the wrapped version
function resolveWrappedToken(network, chain, token) {
    if (isTokenId(token))
        return [false, token];
    if (token === "native") {
        const nativeToken = sdk_base_1.tokens.getNative(network, chain);
        if (!nativeToken)
            throw new Error("Invalid destination token");
        const wrappedKey = nativeToken.wrapped;
        const wrappedToken = sdk_base_1.tokens.getTokenByKey(network, chain, wrappedKey.symbol);
        if (!wrappedToken)
            throw new Error("Invalid wrapped token key: " + wrappedKey);
        const destNativeWrapped = { chain, address: (0, address_1.toNative)(chain, wrappedToken.address) };
        return [true, destNativeWrapped];
    }
    return [false, { chain, address: token }];
}
exports.resolveWrappedToken = resolveWrappedToken;
function isTransactionIdentifier(thing) {
    return thing.chain !== undefined && thing.txid !== undefined;
}
exports.isTransactionIdentifier = isTransactionIdentifier;
function buildConfig(n) {
    const cc = sdk_base_1.chains
        .map((c) => {
        const platform = (0, sdk_base_1.chainToPlatform)(c);
        let nativeChainId = "";
        try {
            nativeChainId = sdk_base_1.nativeChainIds.networkChainToNativeChainId.get(n, c);
        }
        catch { }
        const tokenMap = sdk_base_1.tokens.getTokenMap(n, c);
        const nativeToken = tokenMap
            ? Object.values(tokenMap).find((token) => token.address === "native" && token.wrapped)
            : undefined;
        const wrappedNative = nativeToken ? tokenMap[nativeToken.wrapped.symbol] : undefined;
        return {
            key: c,
            platform,
            network: n,
            chainId: (0, sdk_base_1.toChainId)(c),
            finalityThreshold: sdk_base_1.finality.finalityThreshold.get(c) ?? 0,
            blockTime: sdk_base_1.finality.blockTime(c),
            contracts: (0, contracts_1.getContracts)(n, c),
            nativeTokenDecimals: sdk_base_1.decimals.nativeDecimals(platform),
            nativeChainId,
            tokenMap,
            wrappedNative,
            explorer: sdk_base_1.explorer.explorerConfigs(n, c),
            rpc: sdk_base_1.rpc.rpcAddress(n, c),
        };
    })
        .reduce((acc, curr) => {
        return { ...acc, [curr.key]: curr };
    }, {});
    return cc;
}
exports.buildConfig = buildConfig;
//# sourceMappingURL=types.js.map