import { chainToPlatform, chains, decimals, explorer, finality, isChain, nativeChainIds, rpc, toChainId, tokens, } from "@wormhole-foundation/sdk-base";
import { toNative } from "./address";
import { getContracts } from "./contracts";
export function isTokenId(thing) {
    return (typeof thing === "object" &&
        thing.address !== undefined &&
        thing.chain !== undefined &&
        isChain(thing.chain));
}
export function isSameToken(a, b) {
    if (a.chain !== b.chain)
        return false;
    return canonicalAddress(a) === canonicalAddress(b);
}
export function canonicalAddress(ca) {
    // @ts-ignore
    return ca.address.toNative(ca.chain).toString();
}
// Given a token id, address, or the const string 'native' return
// a TokenId representing either the token itself or the wrapped version
export function resolveWrappedToken(network, chain, token) {
    if (isTokenId(token))
        return [false, token];
    if (token === "native") {
        const nativeToken = tokens.getNative(network, chain);
        if (!nativeToken)
            throw new Error("Invalid destination token");
        const wrappedKey = nativeToken.wrapped;
        const wrappedToken = tokens.getTokenByKey(network, chain, wrappedKey.symbol);
        if (!wrappedToken)
            throw new Error("Invalid wrapped token key: " + wrappedKey);
        const destNativeWrapped = { chain, address: toNative(chain, wrappedToken.address) };
        return [true, destNativeWrapped];
    }
    return [false, { chain, address: token }];
}
export function isTransactionIdentifier(thing) {
    return thing.chain !== undefined && thing.txid !== undefined;
}
export function buildConfig(n) {
    const cc = chains
        .map((c) => {
        const platform = chainToPlatform(c);
        let nativeChainId = "";
        try {
            nativeChainId = nativeChainIds.networkChainToNativeChainId.get(n, c);
        }
        catch { }
        const tokenMap = tokens.getTokenMap(n, c);
        const nativeToken = tokenMap
            ? Object.values(tokenMap).find((token) => token.address === "native" && token.wrapped)
            : undefined;
        const wrappedNative = nativeToken ? tokenMap[nativeToken.wrapped.symbol] : undefined;
        return {
            key: c,
            platform,
            network: n,
            chainId: toChainId(c),
            finalityThreshold: finality.finalityThreshold.get(c) ?? 0,
            blockTime: finality.blockTime(c),
            contracts: getContracts(n, c),
            nativeTokenDecimals: decimals.nativeDecimals(platform),
            nativeChainId,
            tokenMap,
            wrappedNative,
            explorer: explorer.explorerConfigs(n, c),
            rpc: rpc.rpcAddress(n, c),
        };
    })
        .reduce((acc, curr) => {
        return { ...acc, [curr.key]: curr };
    }, {});
    return cc;
}
//# sourceMappingURL=types.js.map